==> haskell-fmlist-0.9.4-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fmlist
version:              0.9.4
visibility:           public
id:                   fmlist-0.9.4-7uEcqVbpNsVAkMNtPrswyY
key:                  fmlist-0.9.4-7uEcqVbpNsVAkMNtPrswyY
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  5fab1c0956b7e89ebdb93b65bafdb9f3
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fmlist-0.9.4
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fmlist-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fmlist
hs-libraries:         HSfmlist-0.9.4-7uEcqVbpNsVAkMNtPrswyY
depends:              base-4.16.4.0
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fmlist-0.9.4-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-fmlist.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 fmlist
version:              0.9.4
visibility:           public
id:                   fmlist-0.9.4-3aArO5t4pvi4CM9i3oC0tu
key:                  fmlist-0.9.4-3aArO5t4pvi4CM9i3oC0tu
license:              BSD-3-Clause
maintainer:           sjoerd@w3future.com
author:               Sjoerd Visscher
homepage:             https://github.com/sjoerdvisscher/fmlist
synopsis:             FoldMap lists
description:
    FoldMap lists are lists represented by their foldMap function.
    FoldMap lists have O(1) cons, snoc and append, just like DLists,
    but other operations might have favorable performance
    characteristics as well. These wild claims are still completely
    unverified though.

category:             Data
abi:                  c74e470a3d66f3c4b1b299b19b173215
exposed:              True
exposed-modules:      Data.FMList
import-dirs:          /usr/lib/ghc-9.4.8/site-local/fmlist-0.9.4
library-dirs:         /usr/lib/ghc-9.4.8/site-local/fmlist-0.9.4
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/fmlist-0.9.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fmlist
hs-libraries:         HSfmlist-0.9.4-3aArO5t4pvi4CM9i3oC0tu
depends:              base-4.17.2.1
haddock-interfaces:   /usr/share/doc/haskell-fmlist/html/fmlist.haddock
haddock-html:         /usr/share/doc/haskell-fmlist/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
